==> zio-aws-ec2_2.12-5.19.12.1-sources.jar: zio/aws/ec2/model/LaunchTemplatePlacementRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  PlacementGroupId,
  Integer,
  DedicatedHostId,
  PlacementGroupName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LaunchTemplatePlacementRequest(
    availabilityZone: Optional[String] = Optional.Absent,
    affinity: Optional[String] = Optional.Absent,
    groupName: Optional[PlacementGroupName] = Optional.Absent,
    hostId: Optional[DedicatedHostId] = Optional.Absent,
    tenancy: Optional[zio.aws.ec2.model.Tenancy] = Optional.Absent,
    spreadDomain: Optional[String] = Optional.Absent,
    hostResourceGroupArn: Optional[String] = Optional.Absent,
    partitionNumber: Optional[Integer] = Optional.Absent,
    groupId: Optional[PlacementGroupId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest = {
    import LaunchTemplatePlacementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
      .builder()
      .optionallyWith(availabilityZone.map(value => value: java.lang.String))(
        _.availabilityZone
      )
      .optionallyWith(affinity.map(value => value: java.lang.String))(
        _.affinity
      )
      .optionallyWith(
        groupName.map(value =>
          PlacementGroupName.unwrap(value): java.lang.String
        )
      )(_.groupName)
      .optionallyWith(
        hostId.map(value => DedicatedHostId.unwrap(value): java.lang.String)
      )(_.hostId)
      .optionallyWith(tenancy.map(value => value.unwrap))(_.tenancy)
      .optionallyWith(spreadDomain.map(value => value: java.lang.String))(
        _.spreadDomain
      )
      .optionallyWith(
        hostResourceGroupArn.map(value => value: java.lang.String)
      )(_.hostResourceGroupArn)
      .optionallyWith(partitionNumber.map(value => value: java.lang.Integer))(
        _.partitionNumber
      )
      .optionallyWith(
        groupId.map(value => PlacementGroupId.unwrap(value): java.lang.String)
      )(_.groupId)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly =
    zio.aws.ec2.model.LaunchTemplatePlacementRequest.wrap(buildAwsValue())
}
object LaunchTemplatePlacementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplatePlacementRequest =
      zio.aws.ec2.model.LaunchTemplatePlacementRequest(
        availabilityZone.map(value => value),
        affinity.map(value => value),
        groupName.map(value => value),
        hostId.map(value => value),
        tenancy.map(value => value),
        spreadDomain.map(value => value),
        hostResourceGroupArn.map(value => value),
        partitionNumber.map(value => value),
        groupId.map(value => value)
      )
    def availabilityZone: Optional[String]
    def affinity: Optional[String]
    def groupName: Optional[PlacementGroupName]
    def hostId: Optional[DedicatedHostId]
    def tenancy: Optional[zio.aws.ec2.model.Tenancy]
    def spreadDomain: Optional[String]
    def hostResourceGroupArn: Optional[String]
    def partitionNumber: Optional[Integer]
    def groupId: Optional[PlacementGroupId]
    def getAvailabilityZone: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getAffinity: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("affinity", affinity)
    def getGroupName: ZIO[Any, AwsError, PlacementGroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
    def getHostId: ZIO[Any, AwsError, DedicatedHostId] =
      AwsError.unwrapOptionField("hostId", hostId)
    def getTenancy: ZIO[Any, AwsError, zio.aws.ec2.model.Tenancy] =
      AwsError.unwrapOptionField("tenancy", tenancy)
    def getSpreadDomain: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("spreadDomain", spreadDomain)
    def getHostResourceGroupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("hostResourceGroupArn", hostResourceGroupArn)
    def getPartitionNumber: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("partitionNumber", partitionNumber)
    def getGroupId: ZIO[Any, AwsError, PlacementGroupId] =
      AwsError.unwrapOptionField("groupId", groupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ) extends zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly {
    override val availabilityZone: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.availabilityZone())
      .map(value => value: String)
    override val affinity: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.affinity())
      .map(value => value: String)
    override val groupName: Optional[PlacementGroupName] = zio.aws.core.internal
      .optionalFromNullable(impl.groupName())
      .map(value => zio.aws.ec2.model.primitives.PlacementGroupName(value))
    override val hostId: Optional[DedicatedHostId] = zio.aws.core.internal
      .optionalFromNullable(impl.hostId())
      .map(value => zio.aws.ec2.model.primitives.DedicatedHostId(value))
    override val tenancy: Optional[zio.aws.ec2.model.Tenancy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tenancy())
        .map(value => zio.aws.ec2.model.Tenancy.wrap(value))
    override val spreadDomain: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.spreadDomain())
      .map(value => value: String)
    override val hostResourceGroupArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.hostResourceGroupArn())
      .map(value => value: String)
    override val partitionNumber: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.partitionNumber())
      .map(value => value: Integer)
    override val groupId: Optional[PlacementGroupId] = zio.aws.core.internal
      .optionalFromNullable(impl.groupId())
      .map(value => zio.aws.ec2.model.primitives.PlacementGroupId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ): zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.104.3-sources.jar: zio/aws/ec2/model/LaunchTemplatePlacementRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  Integer,
  DedicatedHostId,
  PlacementGroupName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LaunchTemplatePlacementRequest(
    availabilityZone: Option[String] = None,
    affinity: Option[String] = None,
    groupName: Option[PlacementGroupName] = None,
    hostId: Option[DedicatedHostId] = None,
    tenancy: Option[zio.aws.ec2.model.Tenancy] = None,
    spreadDomain: Option[String] = None,
    hostResourceGroupArn: Option[String] = None,
    partitionNumber: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest = {
    import LaunchTemplatePlacementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
      .builder()
      .optionallyWith(availabilityZone.map(value => value: java.lang.String))(
        _.availabilityZone
      )
      .optionallyWith(affinity.map(value => value: java.lang.String))(
        _.affinity
      )
      .optionallyWith(
        groupName.map(value =>
          PlacementGroupName.unwrap(value): java.lang.String
        )
      )(_.groupName)
      .optionallyWith(
        hostId.map(value => DedicatedHostId.unwrap(value): java.lang.String)
      )(_.hostId)
      .optionallyWith(tenancy.map(value => value.unwrap))(_.tenancy)
      .optionallyWith(spreadDomain.map(value => value: java.lang.String))(
        _.spreadDomain
      )
      .optionallyWith(
        hostResourceGroupArn.map(value => value: java.lang.String)
      )(_.hostResourceGroupArn)
      .optionallyWith(
        partitionNumber.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.partitionNumber)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly =
    zio.aws.ec2.model.LaunchTemplatePlacementRequest.wrap(buildAwsValue())
}
object LaunchTemplatePlacementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplatePlacementRequest =
      zio.aws.ec2.model.LaunchTemplatePlacementRequest(
        availabilityZone.map(value => value),
        affinity.map(value => value),
        groupName.map(value => value),
        hostId.map(value => value),
        tenancy.map(value => value),
        spreadDomain.map(value => value),
        hostResourceGroupArn.map(value => value),
        partitionNumber.map(value => value)
      )
    def availabilityZone: Option[String]
    def affinity: Option[String]
    def groupName: Option[PlacementGroupName]
    def hostId: Option[DedicatedHostId]
    def tenancy: Option[zio.aws.ec2.model.Tenancy]
    def spreadDomain: Option[String]
    def hostResourceGroupArn: Option[String]
    def partitionNumber: Option[Integer]
    def getAvailabilityZone: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getAffinity: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("affinity", affinity)
    def getGroupName: ZIO[Any, AwsError, PlacementGroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
    def getHostId: ZIO[Any, AwsError, DedicatedHostId] =
      AwsError.unwrapOptionField("hostId", hostId)
    def getTenancy: ZIO[Any, AwsError, zio.aws.ec2.model.Tenancy] =
      AwsError.unwrapOptionField("tenancy", tenancy)
    def getSpreadDomain: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("spreadDomain", spreadDomain)
    def getHostResourceGroupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("hostResourceGroupArn", hostResourceGroupArn)
    def getPartitionNumber: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("partitionNumber", partitionNumber)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ) extends zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly {
    override val availabilityZone: Option[String] =
      scala.Option(impl.availabilityZone()).map(value => value: String)
    override val affinity: Option[String] =
      scala.Option(impl.affinity()).map(value => value: String)
    override val groupName: Option[PlacementGroupName] = scala
      .Option(impl.groupName())
      .map(value => zio.aws.ec2.model.primitives.PlacementGroupName(value))
    override val hostId: Option[DedicatedHostId] = scala
      .Option(impl.hostId())
      .map(value => zio.aws.ec2.model.primitives.DedicatedHostId(value))
    override val tenancy: Option[zio.aws.ec2.model.Tenancy] = scala
      .Option(impl.tenancy())
      .map(value => zio.aws.ec2.model.Tenancy.wrap(value))
    override val spreadDomain: Option[String] =
      scala.Option(impl.spreadDomain()).map(value => value: String)
    override val hostResourceGroupArn: Option[String] =
      scala.Option(impl.hostResourceGroupArn()).map(value => value: String)
    override val partitionNumber: Option[Integer] = scala
      .Option(impl.partitionNumber())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplatePlacementRequest
  ): zio.aws.ec2.model.LaunchTemplatePlacementRequest.ReadOnly = new Wrapper(
    impl
  )
}
